package internal

import (
	"context"
	"fmt"
	"github.com/wechatpay-apiv3/wechatpay-go/core"
	"github.com/wechatpay-apiv3/wechatpay-go/core/option"
	"github.com/wechatpay-apiv3/wechatpay-go/services/cashcoupons"
	"github.com/wechatpay-apiv3/wechatpay-go/utils"
)

func apiSrv(ctx context.Context, config *Config) (*cashcoupons.CouponApiService, error) {
	mchPrivateKey, err := utils.LoadPrivateKeyWithPath(config.PrivateKeyPath)
	if err != nil {
		return nil, fmt.Errorf("load merchant private key error:%v", err)
	}
	opts := []core.ClientOption{
		option.WithWechatPayAutoAuthCipher(config.MchID, config.MchCertificateSerialNumber, mchPrivateKey, config.MchAPIv3Key),
	}
	client, err := core.NewClient(ctx, opts...)
	if err != nil {
		return nil, fmt.Errorf("new wechat pay client err:%v", err)
	}
	svc := cashcoupons.CouponApiService{Client: client}
	return &svc, err
}
