package internal

import (
	"codeup.aliyun.com/6552e56cc3b2728a4557fc18/plugin/proto"
	"context"
	"encoding/json"
	"fmt"
	"github.com/stretchr/testify/assert"
	"testing"
)

var server = &WeiXinCpnService{}

func config() []byte {
	c := &Config{
		MchID:                      "1605446142",
		MchCertificateSerialNumber: "4D081089DEB385316CBDCB55C070287E4920AC76",
		MchAPIv3Key:                "ChengDuLanSeXiongDi1234567890123",
		PrivateKeyPath:             "/Users/lsxd/code/go/other/mq/wx/wechat_private_key.pem",
	}
	marshal, _ := json.Marshal(c)
	return marshal
}

func TestOrder(t *testing.T) {
	request := &proto.OrderRequest{
		Config: config(),
		Order: &proto.OrderRequest_Order{
			OrderNo: "240403164049635931",
			Account: "oO3vO5AxRWgTjmMD38FTvnB5Rq6o",
			Extra:   []byte(`{"app_id":"13100720242", "stock_creator_mchid":"stock_creator_mchid"}`),
		},
		Product: &proto.OrderRequest_Product{
			ProductNo: "3102024032977191",
			Extra:     []byte(`{}`),
		},
	}
	t.Run("TestOrder", func(t *testing.T) {
		got, err := server.Order(context.Background(), request)
		if err != nil {
			t.Errorf("Order() error = %v", err)
			return
		}
		fmt.Printf("%+v", got)
		assert.Equal(t, int(proto.Status_ING), int(got.Result.Status))
	})
}

func TestQuery(t *testing.T) {
	request := &proto.QueryRequest{
		Config: config(),
		Order: &proto.QueryRequest_Order{
			OrderNo: "",
			TradeNo: "69445765514",
			Account: "oO3vO5AxRWgTjmMD38FTvnB5Rq6o",
			Extra:   []byte(`{"app_id":"wx9ed74283ad25bca1"}`),
		},
	}
	t.Run("TestQuery", func(t *testing.T) {
		got, err := server.Query(context.Background(), request)
		if err != nil {
			t.Errorf("Query() error = %v", err)
			return
		}
		fmt.Printf("%+v \n", got)
		//assert.Equal(t, int(proto.Status_SUCCESS), int(got.Result.Status))
	})
}

func TestNotify(t *testing.T) {
	in := &proto.NotifyRequest{
		Config:  config(),
		Queries: []byte(`{"charset":"UTF-8","biz_content":"{&quot;publish_amount&quot;:500,&quot;activity_name&quot;:&quot;\u90ae\u50a8\u6fc0\u6d3b\u793c47\u6ee1100-5&quot;,&quot;user_id&quot;:&quot;2088532467083354&quot;,&quot;gmt_voucher_create&quot;:1720764021383,&quot;voucher_status&quot;:&quot;ENABLED&quot;,&quot;biz_type&quot;:&quot;V_BATCH_PUBLISH&quot;,&quot;activity_id&quot;:&quot;ACT373CCV02109242&quot;,&quot;voucher_id&quot;:&quot;202407120007300235830O26E1ZD&quot;,&quot;order_id&quot;:&quot;2024071200073024358301P7OES3&quot;}","utc_timestamp":"1720764036512","sign":"oplbkc3Dcz7S8\/DSi+tBPDN593EINHQb1G0km7IgKyFfZpaYgjyyBm\/Ic2mHV6nyt9O\/eWJ0aEPLiR+rPJ3W\/ezPJCQbLascF6HshfdQa22holFnuO9xDcUH7IkR0hiQ5QxSJ+oJ6ZPU6+Po\/ercbQvwbUeQouPuZC+xWba6sznTEK7aMkv9sZJpbj3P4wD1HZKC50LEjKSAug7GZNv7B3wOqXA+Ta26l8cg2z8qHWAAdF6cYdgZ63uPKMOPDTT3gRj\/UnebE3Xjc62PYUsZJhdclJi5hW3CTTbubEmBW482rgNMIc6I+LRY8Nvspu\/8MkxU0bVsoxBEe1s0VqSLzA==","app_id":"2021004125622196","version":"1.1","sign_type":"RSA2","notify_id":"2024071200262140036056588190308607","msg_method":"alipay.user.voucher.dtbankcust.notify"}`),
		Headers: []byte(``),
		Body:    []byte(``),
	}
	t.Run("TestNotify", func(t *testing.T) {
		got, err := server.Notify(context.Background(), in)
		if err != nil {
			t.Errorf("Notify() error = %v", err)
			return
		}
		fmt.Printf("TestNotify : %+v \n", got)
		assert.Equal(t, int(proto.Status_SUCCESS), int(got.Result.Status))
	})
}
