package internal

import (
	"codeup.aliyun.com/6552e56cc3b2728a4557fc18/plugin/proto"
	"context"
	"encoding/json"
	"errors"
	"fmt"
	"github.com/carlmjohnson/requests"
	"plugins/zltx/internal/po"
)

// 插件通信信息,若不对应则会报错panic
const (
	Tag         = "zltx"
	Version     = 1
	CookieKey   = "zltx"
	CookieValue = "zltx"
)

const (
	orderMethod = "/recharge/order"
	queryMethod = "/recharge/query"
)

type ZltxService struct{}

func (p *ZltxService) Order(ctx context.Context, request *proto.OrderRequest) (*proto.OrderResponse, error) {
	c, err := transConfig(request.Config)
	if err != nil {
		return nil, err
	}
	uv, err := req(c.orderReq(request), c.AppKey)
	if err != nil {
		return nil, err
	}

	var response po.OrderResp
	err = requests.URL(c.BaseUri + orderMethod).BodyForm(uv).ToJSON(&response).Fetch(ctx)
	if err != nil {
		return nil, fmt.Errorf("请求异常，msg:" + err.Error())
	}

	response.SetCodeStr()
	if !response.CodeStr.IsRechargeSuccess() {
		return nil, fmt.Errorf("请求错误,msg:" + response.Message)
	}

	return orderResp(request, response), nil
}

func (p *ZltxService) Query(ctx context.Context, request *proto.QueryRequest) (*proto.QueryResponse, error) {
	c, err := transConfig(request.Config)
	if err != nil {
		return nil, err
	}
	uv, err := req(c.queryReq(request), c.AppKey)
	if err != nil {
		return nil, err
	}

	var response po.QueryResp
	err = requests.URL(c.BaseUri + queryMethod).BodyForm(uv).ToJSON(&response).Fetch(ctx)
	if err != nil {
		return nil, fmt.Errorf("请求异常，msg:" + err.Error())
	}

	if !response.Code.IsSuccess() {
		return nil, errors.New("请求错误，msg:" + response.Message)
	}

	return queryResp(request, response), nil
}

func (p *ZltxService) Notify(_ context.Context, request *proto.NotifyRequest) (*proto.NotifyResponse, error) {
	c, err := transConfig(request.Config)
	if err != nil {
		return nil, err
	}
	var poReq po.Notify
	err = json.Unmarshal(request.Body, &poReq)
	if err != nil {
		return nil, fmt.Errorf("解析异常，msg:" + err.Error())
	}

	err = poReq.Validate()
	if err != nil {
		return nil, err
	}
	if !verify(poReq, c.AppKey) {
		return nil, errors.New("验签不通过")
	}

	return notifyResp(poReq), nil
}
